package com.sunwin.visitorapp;

import android.Manifest;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.app.ActivityCompat;

import com.sunwin.visitorapp.utils.AppManager;
import com.sunwin.visitorapp.utils.Constants;
import com.sunwin.visitorapp.utils.SharePrefenceUtils;
import com.sunwin.visitorapp.utils.ToastUtils;

import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class SplashActivity extends AppCompatActivity {

    private static final int REQUEST_FOR_PERMISSION = 100;
    private static final String TAG = "SplashActivity";
    private ArrayList<String> permissions;
    MyHandler myHandler = new MyHandler(this);

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_splash);
        AppManager.getAppManager().addActivity(this);
        permissions = new ArrayList<>();
        initData();
        myHandler.sendEmptyMessageDelayed(0, 500);
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        AppManager.getAppManager().removeActivity(this);
        if (myHandler != null) {
            myHandler.removeMessages(0);
        }
    }

    private void initData() {
        initPermission();
    }

    private void initPermission() {

        permissions.add(Manifest.permission.WRITE_EXTERNAL_STORAGE);
        permissions.add(Manifest.permission.READ_PHONE_STATE);
        permissions.add(Manifest.permission.CAMERA);

    }


    static class MyHandler extends Handler {
        WeakReference<SplashActivity> mWeakReference;

        public MyHandler(SplashActivity activity) {
            mWeakReference = new WeakReference<SplashActivity>(activity);
        }

        @Override
        public void handleMessage(Message msg) {
            final SplashActivity activity = mWeakReference.get();
            if (activity != null) {
                activity.getPermission();
            }
        }
    }

    private void getPermission() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            requestPer2();
        } else {
            openApplication();
        }
    }

    private void requestPer2() {
        Iterator<String> it = permissions.iterator();
        while (it.hasNext()) {
            String permission = it.next();
            //检查权限是否已经申请
            int hasPermission = ActivityCompat.checkSelfPermission(this, permission);//ActivityCompat.checkSelfPermission(this, permission)todo
            if (hasPermission == PackageManager.PERMISSION_GRANTED) {
                it.remove();
            }
        }
        if (permissions.size() == 0) {
            openApplication();
            return;
        }
        String[] permissionStr = permissions.toArray(new String[0]);
        //正式请求权限
        ActivityCompat.requestPermissions(this, permissionStr, REQUEST_FOR_PERMISSION);

    }





    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);
        switch (requestCode) {
            case REQUEST_FOR_PERMISSION:
                if (grantResults.length > 0 && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
                    openApplication();
                } else {
                    ToastUtils.showToast("请您授予应用相应权限!");
                }
                return;

            default:
                break;
        }
    }


    /**
     * 进入应用程序
     */
    private void openApplication() {
        boolean isLogin = SharePrefenceUtils.getBoolean(Constants.ISharePrefence.LOGINTAG, false);
        if (isLogin) {
            gotoMain();
        } else {
            gotoLogin();
        }
    }

    private void gotoMain() {
        Intent intent = new Intent(this, MainActivity.class);
        startActivity(intent);
        finish();
    }

    private void gotoLogin() {
        Intent intent = new Intent(this, LoginActivity.class);
        startActivity(intent);
        finish();
    }
}
